@@ -1,6 +1,6 @@
 package Crypt::Hill;
 
-$Crypt::Hill::VERSION   = '0.06';
+$Crypt::Hill::VERSION   = '0.07';
 $Crypt::Hill::AUTHORITY = 'cpan:MANWAR';
 
 =head1 NAME
@@ -9,7 +9,7 @@ Crypt::Hill - Interface to the Hill cipher (2x2).
 
 =head1 VERSION
 
-Version 0.06
+Version 0.07
 
 =cut
 
@@ -159,7 +159,7 @@ Mohammad S Anwar, C<< <mohammad.anwar at yahoo.com> >>
 
 =head1 REPOSITORY
 
-L<https://github.com/Manwar/Crypt-Hill>
+L<https://github.com/manwar/Crypt-Hill>
 
 =head1 BUGS
 
@@ -198,7 +198,7 @@ L<http://search.cpan.org/dist/Crypt-Hill/>
 
 =head1 LICENSE AND COPYRIGHT
 
-Copyright (C) 2014 - 2015 Mohammad S Anwar.
+Copyright (C) 2014 - 2016 Mohammad S Anwar.
 
 This  program  is  free software; you can redistribute it and/or modify it under
 the  terms  of the the Artistic License (2.0). You may obtain a copy of the full
